@@ -86,8 +86,16 @@ class PdfPage(enum.IntEnum):
     LEFT    = 5
     #: Full page + draw another page for notes, which is after the slides
     AFTER   = 6
-    #: Complemntary of AFTER: for a notes page, the slide page is BEFORE by half a document
+    #: Complementary of AFTER: for a notes page, the slide page is BEFORE by half a document
     BEFORE  = 7
+    #: Slides on even pages (0-indexed), notes on uneven pages
+    ODD     = 8
+    #: Complementary of ODD
+    EVEN    = 9
+    #: An arbitrary mapping of notes pages to slide pages
+    MAP     = 10
+    #: Reverse the arbitrary mapping MAP
+    RMAP    = 11
 
     def complement(val):
         """ Return the enum value for the other part of the page.
@@ -113,6 +121,10 @@ class PdfPage(enum.IntEnum):
             return 'vertical'
         elif val == PdfPage.AFTER or val == PdfPage.BEFORE:
             return 'page number'
+        elif val == PdfPage.EVEN or val == PdfPage.ODD:
+            return 'page parity'
+        elif val == PdfPage.MAP or val == PdfPage.RMAP:
+            return 'page mapping'
         else:
             return None
 
@@ -681,8 +693,8 @@ class Page(object):
 class Document(object):
     """ This is the main document handling class.
 
-    .. note:: The internal page numbering scheme is the same as in Poppler: it
-       starts at 0.
+    The page numbering starts as 0 and is aware of notes (i.e. number of pages may change to account for note pages).
+    The document page numbers are the same as in Poppler, and also start at 0 but do not depend on notes.
 
     Args:
         builder (:class:`pympress.builder.Builder`):  A builder to load callbacks
@@ -705,14 +717,16 @@ class Document(object):
     pages_cache = {}
     #: `set` of :class:`~pathlib.Path` representing the temporary files which need to be removed
     temp_files = set()
-    #: History of pages we have visited
+    #: History of pages we have visited, using note-aware page numbers
     history = []
     #: Our position in the history
     hist_pos = -1
-    #: `dict` of all the page labels
+    #: `list` of slide page labels, indexed on note-aware page numbers
     page_labels = []
-    #: `bool` indicating whether the second half of pages are in fact notes pages
-    notes_after = False
+    #: `list` of all the page labels, indexed on document page numbers
+    doc_page_labels = []
+    #: `list` of (slide's document page number, notes' document page number) tuples, or `None` if there are no notes
+    notes_mapping = None
     #: `bool` indicating whether there were modifications to the document
     changes = False
 
@@ -745,13 +759,10 @@ class Document(object):
         else:
             self.path = None
 
-        # Pages number
-        if pop_doc is not None:
-            self.nb_pages = self.doc.get_n_pages()
-            self.page_labels = [self.doc.get_page(n).get_label() for n in range(self.nb_pages)]
-        else:
-            self.nb_pages = 0
-            self.page_labels = []
+        # Pages numbers and labels
+        self.nb_pages = 0 if pop_doc is None else self.doc.get_n_pages()
+        self.doc_page_labels = [self.doc.get_page(n).get_label() for n in range(self.nb_pages)]
+        self.page_labels = self.doc_page_labels
 
         # Pages cache
         self.pages_cache = {}
@@ -902,6 +913,9 @@ class Document(object):
         Returns:
             :class:`~pympress.document.PdfPage`: the notes mode
         """
+        if any(label.startswith('notes:') for label in self.page_labels):
+            return PdfPage.MAP
+
         page = self.page(current_page)
         if page is None or not page.can_render():
             return PdfPage.NONE
@@ -941,13 +955,37 @@ class Document(object):
         return PdfPage.NONE
 
 
-    def set_notes_after(self, notes_after):
-        """ Set whether there are notes pages after normal pages (aka Libreoffice notes mode)
+    def set_notes_pos(self, notes_direction):
+        """ Set whether where the notes pages are relative to normal pages
+
+        Valid values are returned by :meth:`~pympress.document.PdfPage.direction`
+        - page number (aka Libreoffice notes mode)
+        - page parity (can not be detected automatically, where every other page contains notes)
+        - page mapping (where labels of notes pages are corresponding slide labels prefixed with “notes:”)
 
         Args:
-            notes_after (`bool`):  Whether there are notes pages
+            notes_direction (`str`):  Where the notes pages are
         """
-        self.notes_after = notes_after
+        if notes_direction == 'page number':
+            self.notes_mapping = [(n, n + self.nb_pages // 2) for n in range(self.nb_pages // 2)]
+        elif notes_direction == 'page parity':
+            self.notes_mapping = [(n, n + 1) for n in range(0, self.nb_pages, 2)]
+        elif notes_direction == 'page mapping':
+            notes_mapping = collections.OrderedDict()
+            for n, (label, prev_label) in enumerate(zip(self.doc_page_labels, [None, *self.doc_page_labels[:-1]])):
+                # Here the condition (could be adjusted) is 2 successive pages labeled <label> and notes:<label>,
+                # with the prior page not being a notes page.
+                if n - 1 in notes_mapping and label == 'notes:' + prev_label:
+                    notes_mapping[n - 1] = n
+                else:
+                    notes_mapping[n] = None
+            self.notes_mapping = list(notes_mapping.items())
+        else:
+            self.notes_mapping = None
+            self.page_labels = self.doc_page_labels
+            return
+
+        self.page_labels = [self.doc_page_labels[page] for page, note in self.notes_mapping]
 
 
     def page(self, number):
@@ -962,6 +1000,11 @@ class Document(object):
         if number >= self.pages_number() or number < 0:
             return None
 
+        if self.notes_mapping is not None:
+            number = self.notes_mapping[number][0]
+            if number < 0:
+                return None
+
         if number not in self.pages_cache:
             self.pages_cache[number] = Page(self.doc.get_page(number), number, self)
         return self.pages_cache[number]
@@ -979,8 +1022,11 @@ class Document(object):
         if number >= self.pages_number() or number < 0:
             return None
 
-        if self.notes_after:
-            number = number + self.pages_number()
+        if self.notes_mapping is not None:
+            number = self.notes_mapping[number][1]
+
+        if number is None:
+            return None
 
         if number not in self.pages_cache:
             self.pages_cache[number] = Page(self.doc.get_page(number), number, self)
@@ -993,7 +1039,7 @@ class Document(object):
         Returns:
             `int`: the number of pages in the document
         """
-        return (self.nb_pages // 2) if self.notes_after else self.nb_pages
+        return len(self.notes_mapping) if self.notes_mapping is not None else self.nb_pages
 
 
     def has_labels(self):
@@ -1002,7 +1048,7 @@ class Document(object):
         Returns:
             `bool`: False iff there are no labels or they are just the page numbers
         """
-        return self.page_labels != [str(n + 1) for n in range(self.nb_pages)]
+        return self.doc_page_labels != [str(n + 1) for n in range(self.nb_pages)]
 
 
     def lookup_label(self, label, prefix_unique=True):
@@ -1044,7 +1090,7 @@ class Document(object):
 
 
     def goto(self, number):
-        """ Switch to another page.
+        """ Switch to another page. Validates the number and returns one in the correct range. Also updates history.
 
         Args:
             number (`int`):  number of the destination page
