@@ -122,6 +122,14 @@ class Scribbler(builder.Builder):
 
     #: `int` that is the currently selected element
     active_preset = -1
+    #: `int` to remember the previously selected element, before holding “eraser”
+    previous_preset = -1
+    #: `list` that contains the modifiers which, when held on scribble start, toggle the eraser
+    toggle_erase_modifiers = []
+    #: `list` that contains the non-modifier shortcuts which, when held on scribble start, toggle the eraser
+    toggle_erase_shortcuts = []
+    #: `str` or `None` that indicates whether a modifier + click or a held shortcut is toggling the eraser
+    toggle_erase_source = None
 
     #: The :class:`~Gio.Action` that contains the currently selected pen
     pen_action = None
@@ -132,6 +140,8 @@ class Scribbler(builder.Builder):
     # per-page means we manage a set of scribbles per document page, and clear or restore them on page change
     # per-label means we manage a set of scribbles per document page, but defined by label and not page number
     highlight_mode = 'single-page'
+    #: `bool` indicating whether we exit highlighting mode on page change
+    page_change_exits = True
 
     #: `dict` of scribbles per page
     remembered_scribbles = {}
@@ -190,6 +200,7 @@ class Scribbler(builder.Builder):
         self.adjust_tools_orientation()
 
         active_pen = config.get('highlight', 'active_pen')
+        self.page_change_exits = config.getboolean('highlight', 'page_change_exits')
         self.setup_actions({
             'highlight':         dict(activate=self.switch_scribbling, state=False),
             'highlight-use-pen': dict(activate=self.load_preset, state=active_pen, parameter_type=str, enabled=False),
@@ -197,16 +208,34 @@ class Scribbler(builder.Builder):
             'highlight-redo':    dict(activate=self.redo_scribble),
             'highlight-undo':    dict(activate=self.pop_scribble),
             'highlight-mode':    dict(activate=self.set_mode, state=self.highlight_mode, parameter_type=str),
+            'highlight-page-exit': dict(activate=self.page_change_action, state=self.page_change_exits),
             'highlight-tools-orientation': dict(activate=self.set_tools_orientation, state=self.tools_orientation,
                                                 parameter_type=str),
         })
 
+        hold_erase = [Gtk.accelerator_parse(keys) for keys in config.shortcuts.get('highlight-hold-to-erase', [])]
+        self.toggle_erase_modifiers = [mod for keycode, mod in hold_erase if not keycode]
+        self.toggle_erase_shortcuts = [(keycode, mod) for keycode, mod in hold_erase if keycode]
 
         self.pen_action = self.get_application().lookup_action('highlight-use-pen')
         self.load_preset(self.pen_action, int(active_pen) if active_pen.isnumeric() else 0)
         self.set_mode(None, GLib.Variant.new_string(config.get('highlight', 'mode')))
 
 
+    def page_change_action(self, gaction, param):
+        """ Change whether we exit or stay in highlighting mode on page changes
+
+        Args:
+            gaction (:class:`~Gio.Action`): the action triggering the call
+            param (:class:`~GLib.Variant`): the new mode as a string wrapped in a GLib.Variant
+        """
+        self.page_change_exits = not gaction.get_state().get_boolean()
+        self.config.set('highlight', 'page_change_exits', 'on' if self.page_change_exits else 'off')
+        gaction.change_state(GLib.Variant.new_boolean(self.page_change_exits))
+
+        return True
+
+
     def set_mode(self, gaction, param):
         """ Change the mode of clearing and restoring highlights
 
@@ -300,6 +329,37 @@ class Scribbler(builder.Builder):
         return self.scribble_drawing
 
 
+    def key_event(self, widget, event):
+        """ Handle key events to activate the eraser while the shortcut is held
+
+        Args:
+            widget (:class:`~Gtk.Widget`):  the widget which has received the event.
+            event (:class:`~Gdk.Event`):  the GTK event.
+
+        Returns:
+            `bool`: whether the event was consumed
+        """
+        if not self.scribbling_mode:
+            return False
+        elif event.type != Gdk.EventType.KEY_PRESS and event.type != Gdk.EventType.KEY_RELEASE:
+            return False
+        elif not (*event.get_keyval()[1:], event.get_state()) in self.toggle_erase_shortcuts:
+            return False
+
+        if event.type == Gdk.EventType.KEY_PRESS and self.active_preset and self.toggle_erase_source is None:
+            self.previous_preset = self.active_preset
+            self.toggle_erase_source = 'shortcut'
+            self.load_preset(target=0)
+        elif event.type == Gdk.EventType.KEY_RELEASE and self.toggle_erase_source == 'shortcut' \
+                and self.previous_preset and not self.active_preset:
+            self.load_preset(target=self.previous_preset)
+            self.previous_preset = 0
+            self.toggle_erase_source = None
+        else:
+            return False
+        return True
+
+
     def toggle_scribble(self, widget, event):
         """ Start/stop drawing scribbles.
 
@@ -314,6 +374,12 @@ class Scribbler(builder.Builder):
             return False
 
         if event.get_event_type() == Gdk.EventType.BUTTON_PRESS:
+            if any(mod & event.get_state() == mod for mod in self.toggle_erase_modifiers) and self.active_preset \
+                    and self.toggle_erase_source is None:
+                self.previous_preset = self.active_preset
+                self.toggle_erase_source = 'modifier'
+                self.load_preset(target=0)
+
             self.scribble_list.append((self.scribble_color, self.scribble_width, []))
             self.scribble_drawing = True
 
@@ -321,6 +387,12 @@ class Scribbler(builder.Builder):
         elif event.get_event_type() == Gdk.EventType.BUTTON_RELEASE:
             self.scribble_drawing = False
             self.prerender()
+
+            if not self.active_preset and self.previous_preset and self.toggle_erase_source == 'modifier':
+                self.load_preset(target=self.previous_preset)
+                self.previous_preset = 0
+                self.toggle_erase_source = None
+
             return True
 
         return False
@@ -714,6 +786,10 @@ class Scribbler(builder.Builder):
         self.scribble_color_selector.set_sensitive(target != 'eraser')
         self.scribble_width_selector.set_sensitive(target != 'eraser')
 
+        # Re-draw the eraser
+        self.scribble_p_da.queue_draw()
+        self.c_da.queue_draw()
+
         return True
 
 
