@@ -282,6 +282,8 @@ class UI(builder.Builder):
         self.connect_signals(self)
 
         for action, shortcut_list in self.config.shortcuts.items():
+            if action == 'highlight-hold-to-erase':
+                continue  # Not really an action but we define a shortcut for it
             self.app.set_accels_for_action('app.' + action, shortcut_list)
 
         # Common to both windows
@@ -494,7 +496,7 @@ class UI(builder.Builder):
         self.shortcuts_window = shortcuts_builder.get_object('shortcuts_window')
 
         for command, shortcut_list in self.config.items('shortcuts'):
-            display_shortcut = shortcuts_builder.get_object('shortcut_' + command)
+            display_shortcut = shortcuts_builder.get_object('shortcut_' + command.replace('-', '_').replace('::', '_'))
             if display_shortcut is not None:
                 display_shortcut.props.accelerator = shortcut_list
 
@@ -694,7 +696,6 @@ class UI(builder.Builder):
             self.file_watcher.stop_watching()
 
         self.current_page = self.preview_page = self.doc.goto(page)
-        self.doc.goto(self.current_page)
 
         # Guess notes mode by default if the document has notes
         if not reloading:
@@ -709,7 +710,7 @@ class UI(builder.Builder):
             if target_mode:
                 self.app.activate_action('notes-pos', target_mode.name.lower())
         else:
-            self.doc.set_notes_after(self.notes_mode.direction() == 'page number')
+            self.doc.set_notes_pos(self.notes_mode.direction())
 
         # Some things that need updating
         self.cache.swap_document(self.doc)
@@ -1090,10 +1091,10 @@ class UI(builder.Builder):
         page_notes = self.doc.notes_page(self.preview_page)
 
         # Aspect ratios and queue redraws
-        if draw_notes:
+        if draw_notes and page_notes is not None:
             note_pr = page_notes.get_aspect_ratio(draw_notes)
             self.p_frame_notes.set_property('ratio', note_pr)
-            self.p_da_notes.queue_draw()
+        self.p_da_notes.queue_draw()
 
         preview_pr = page_preview.get_aspect_ratio(draw_page)
 
@@ -1130,7 +1131,8 @@ class UI(builder.Builder):
             return
 
         # Remove scribbles and scribbling/zooming modes
-        self.scribbler.disable_scribbling()
+        if self.scribbler.page_change_exits:
+            self.scribbler.disable_scribbling()
         self.scribbler.page_change(self.preview_page, page_preview.label())
         self.zoom.stop_zooming()
 
@@ -1176,14 +1178,18 @@ class UI(builder.Builder):
             if page is None:
                 return
         else:
-            logger.warning(_('Unknown widget "{}" to draw'.format(widget.getname())))
+            logger.warning(_('Unknown widget "{}" to draw'.format(widget.get_name())))
+
+        if page is None:
+            if widget is not self.p_da_notes or self.notes_mode.direction() != 'page mapping':
+                logger.warning(_('Unexpected missing page to draw for widget "{}"'.format(widget.get_name())))
             return
 
         if not page.can_render():
             return
 
         name = widget.get_name().rstrip('0123456789')
-        nb = page.number()
+        nb = page.number()  # Use PDF page numbering for the cache
         wtype = self.cache.get_widget_type(name)
         ww, wh = widget.get_allocated_width(), widget.get_allocated_height()
         window = widget.get_window()
@@ -1252,28 +1258,6 @@ class UI(builder.Builder):
     ############################     User inputs      ############################
     ##############################################################################
 
-    def on_navigation(self, widget, event):
-        """ Manage key presses for both windows.
-
-        Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred (ignored)
-            event (:class:`~Gdk.Event`):  the event that occurred
-
-        Returns:
-            `bool`: whether the event was consumed
-        """
-        if event.type != Gdk.EventType.KEY_PRESS:
-            return False
-
-        # Try passing events to special-behaviour widgets (spinner, ett, zooming, scribbler) in case they are enabled
-        if self.page_number.on_keypress(widget, event):
-            return True
-        elif self.est_time.on_keypress(widget, event):
-            return True
-
-        return False
-
-
     def validate_current_input(self, gaction, param=None):
         """ Handle the action validating the input, if applicable.
 
@@ -1298,6 +1282,8 @@ class UI(builder.Builder):
         """
         if self.annotations.key_event(widget, event):
             return True
+        elif self.scribbler.key_event(widget, event):
+            return True
 
         return False
 
@@ -1671,7 +1657,7 @@ class UI(builder.Builder):
         if target_mode == self.chosen_notes_mode:
             return False
 
-        # Update the choice, except for NONE or BEFORE/AFTER
+        # Update the choice, except for NONE or BEFORE/AFTER or EVEN/ODD
         if target_mode:
             self.chosen_notes_mode = target_mode
             gaction.change_state(target)
@@ -1702,10 +1688,22 @@ class UI(builder.Builder):
             return False
 
         self.scribbler.disable_scribbling()
-        self.doc.set_notes_after(target_mode.direction() == 'page number')
+        self.doc.set_notes_pos(target_mode.direction())
 
         self.load_layout(self.layout_name(target_mode))
 
+        # Transform or clip page number appropriately
+        renumber_page = (target_mode.direction() == 'page parity') - (self.notes_mode.direction() == 'page parity')
+        if renumber_page < 0:
+            self.preview_page *= 2
+            self.current_page *= 2
+        elif renumber_page > 0:
+            self.preview_page //= 2
+            self.current_page //= 2
+        elif target_mode.direction() == 'page number':
+            self.preview_page = min(self.preview_page, self.doc.pages_number())
+            self.current_page = min(self.current_page, self.doc.pages_number())
+
         self.notes_mode = target_mode
         page_type = self.notes_mode.complement()
 
